@@ -1,5 +1,5 @@
 package Mira::View::Feed;
-$Mira::View::Feed::VERSION = '00.07.31';
+$Mira::View::Feed::VERSION = '00.07.32';
 
 use strict;
 use warnings;
@@ -139,7 +139,7 @@ sub template {
           push @$posts, $allentries->{$utid};
         }
         $vars->{POSTS} = $posts;
-        my $feedindex = catfile($pensource, 'public', $config->{$floor}->{root}, 'feed.xml');
+        my $feedindex = catfile($pensource, $config->{_default}->{publishDIR}, $config->{$floor}->{root}, 'feed.xml');
         $floor_index->process('atom.tt2', $vars, $feedindex, { binmode => ':utf8' })
             || die $floor_index->error(), "\n";
 
