@@ -1,5 +1,5 @@
 package Mira::View::Main;
-$Mira::View::Main::VERSION = '00.07.31';
+$Mira::View::Main::VERSION = '00.07.32';
 
 use strict;
 use warnings;
@@ -75,7 +75,7 @@ sub template {
 
   my $ext = $config->{_default}->{output_extension} || 'html';
   $ext =~ s{^\.+}{};
-  my $index = catfile($pensource, 'public', $config->{_default}->{root}, "index.$ext");
+  my $index = catfile($pensource, $config->{_default}->{publishDIR}, $config->{_default}->{root}, "index.$ext");
   $root_index->process('main.tt2', $vars, $index, { binmode => ':utf8' })
       || die $root_index->error(), "\n";
 
